## Contributing to Arbor

First off, thank you for considering contributing to Arbor! It's people like you that
make Arbor such a great tool. Feel welcome and read the following sections in order to
know how to ask questions and how to work on something.

There are many ways to contribute: writing tutorials or blog posts, improving the
documentation, submitting bug reports and feature requests or writing code which can be
incorporated into Arbor itself.

The Arbor documentation has a [Contributing section](https://docs.arbor-sim.org/en/latest/contrib)
where we have laid out how you can go about making your contribution.

## Get in touch

You can reach out in the following ways:

* [Gitter](https://gitter.im/arbor-sim/community) and [Matrix](https://matrix.to/#/#arbor-sim_community:gitter.im). We encourage you to use the discussion board for help with modelling. Any other questions or remarks regarding using Arbor for your research are of course also welcome.
* [Email](mailto:contact@arbor-sim.org).
